#[non_exhaustive]pub enum Request<'a> {
Destroy,
SetRadius {
top_left: u32,
top_right: u32,
bottom_right: u32,
bottom_left: u32,
},
UnsetRadius,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
Destroy the corner-radius object
Informs the server that the client will no longer be using this protocol object. The corner radius will be unset on the next commit.
This is a destructor, once sent this object cannot be used any longer.
SetRadius
Set corner radius
This request sets the hinted corner radius values for rectangular windows.
The corner radius hint is double-buffered state and will be applied on the next wl_surface.commit.
The value is given in logical space relative to the window geometry of the associated xdg_toplevel. If any value exceeds a quarter of either dimension of the window geometry the radius_too_large protocol error is raised.
Fields
UnsetRadius
Unset corner radius
Unsets any previously hinted corner radius values without invalidating the object for later use. Can be used by clients that possibly have temporary irregular shapes.
Implementations