pub struct CosmicCornerRadiusToplevelV1 { /* private fields */ }wayland and Linux only.Expand description
corner radius toplevel
The corner-radius object provides a way to specify a corner-radius for it’s associated toplevel.
If the xdg_toplevel associated with the cosmic_corner_radius_toplevel_v1 object has been destroyed, this object becomes inert. Any further requests other than destroy will raise the toplevel_destroyed protocol error.
This interface has no events.
Implementations
Sourceimpl CosmicCornerRadiusToplevelV1
impl CosmicCornerRadiusToplevelV1
Sourcepub fn destroy(&self)
pub fn destroy(&self)
Destroy the corner-radius object
Informs the server that the client will no longer be using this protocol object. The corner radius will be unset on the next commit.
Sourcepub fn set_radius(
&self,
top_left: u32,
top_right: u32,
bottom_right: u32,
bottom_left: u32,
)
pub fn set_radius( &self, top_left: u32, top_right: u32, bottom_right: u32, bottom_left: u32, )
Set corner radius
This request sets the hinted corner radius values for rectangular windows.
The corner radius hint is double-buffered state and will be applied on the next wl_surface.commit.
The value is given in logical space relative to the window geometry of the associated xdg_toplevel. If any value exceeds a quarter of either dimension of the window geometry the radius_too_large protocol error is raised.
Sourcepub fn unset_radius(&self)
pub fn unset_radius(&self)
Unset corner radius
Unsets any previously hinted corner radius values without invalidating the object for later use. Can be used by clients that possibly have temporary irregular shapes.